@@ -1,8 +1,8 @@
 #pragma once
 
-
 #include <string>
-namespace lsp {
+namespace lsp
+{
 /**
  * The <code>IProgressMonitor</code> interface is implemented
  * by objects that monitor the progress of an activity; the methods
@@ -36,18 +36,19 @@ namespace lsp {
  * Clients may implement this interface.
  * </p>
  */
-        class  IProgressMonitor {
-        public:
-                virtual ~IProgressMonitor()
-                {
-                }
+class IProgressMonitor
+{
+public:
+    virtual ~IProgressMonitor()
+    {
+    }
 
-                /** Constant indicating an unknown amount of work.
+    /** Constant indicating an unknown amount of work.
                  */
 
-                const static int UNKNOWN = -1;
+    static int const UNKNOWN = -1;
 
-        /**
+    /**
                 * Notifies that the main task is beginning.  This must only be called once
                 * on a given progress monitor instance.
                 *
@@ -57,33 +58,30 @@ namespace lsp {
                 *  the implemenation is free to indicate progress in a way which
                 *  doesn't require the total number of work units in advance.
                 */
-                virtual void beginTask(void* , int totalWork)
-                {
+    virtual void beginTask(void*, int totalWork) {
 
-                };
-                /**
+    };
+    /**
                  * Notifies that the work is done; that is, either the main task is completed
                  * or the user canceled it. This method may be called more than once
                  * (implementations should be prepared to handle this case).
                  */
 
-                virtual void endTask(void*, int totalWork)
-                {
+    virtual void endTask(void*, int totalWork)
+    {
+    }
 
-                }
+    virtual void done(void*) = 0;
 
-                virtual void done(void*) = 0;
-
-                /**
+    /**
                  * Internal method to handle scaling correctly. This method
                  * must not be called by a client. Clients should
                  * always use the method <code>worked(int)</code>.
                  */
-                virtual void internalWorked(double work)
-                {
-
-                }
-                /**
+    virtual void internalWorked(double work)
+    {
+    }
+    /**
                  * Returns whether cancelation of current operation has been requested.
                  * Long-running operations should poll to see if cancelation
                  * has been requested.
@@ -92,8 +90,8 @@ namespace lsp {
                  *    and <code>false</code> otherwise
                  * @see #setCanceled
                  */
-                virtual bool isCanceled() = 0;
-                /**
+    virtual bool isCanceled() = 0;
+    /**
                  * Sets the cancel state to the given value.
                  *
                  * @param value <code>true</code> indicates that cancelation has
@@ -102,8 +100,8 @@ namespace lsp {
                  *
                  * @see #isCanceled
                  */
-                virtual void setCanceled(bool value) = 0;
-                /**
+    virtual void setCanceled(bool value) = 0;
+    /**
                  * Sets the task name to the given value. This method is used to
                  * restore the task label after a nested operation was executed.
                  * Normally there is no need for clients to call this method.
@@ -111,21 +109,19 @@ namespace lsp {
                  * @param name the name (or description) of the main task
                  * @see #beginTask(java.lang.const wstring&, int)
                  */
-                virtual void setTaskName(void*)
-                {
+    virtual void setTaskName(void*) {
 
-                };
-                /**
+    };
+    /**
                  * Notifies that a subtask of the main task is beginning.
                  * Subtasks are optional; the main task might not have subtasks.
                  *
                  * @param name the name (or description) of the subtask
                  */
-                virtual void subTask(void* )
-                {
-
-                }
-                /**
+    virtual void subTask(void*)
+    {
+    }
+    /**
                  * Notifies that a given number of work unit of the main task
                  * has been completed. Note that this amount represents an
                  * installment, as opposed to a cumulative amount of work done
@@ -133,11 +129,10 @@ namespace lsp {
                  *
                  * @param work the number of work units just completed
                  */
-                virtual void worked(int work)
-                {
+    virtual void worked(int work) {
 
-                };
+    };
 
-                virtual void catch_exception(void*) = 0;
-        };
-}
+    virtual void catch_exception(void*) = 0;
+};
+} // namespace lsp
