@@ -10,28 +10,29 @@
 #include <ppltasks.h>
 #endif
 
-struct  StatusReport {
+struct StatusReport
+{
 
-        std::string ToString() const
-        {
-                std::string info;
-                info += "type:" + type + "\n";
-                info += "message:" + message + "\n";
-                return info;
-        }
-        /**
+    std::string ToString() const
+    {
+        std::string info;
+        info += "type:" + type + "\n";
+        info += "message:" + message + "\n";
+        return info;
+    }
+    /**
          * The message type. See {
          *
          */
 
-        std::string  type;
-        /**
+    std::string type;
+    /**
          * The actual message
          *
          */
 
-        std::string  message;
-        MAKE_SWAP_METHOD(StatusReport, type, message);
+    std::string message;
+    MAKE_SWAP_METHOD(StatusReport, type, message);
 };
 MAKE_REFLECT_STRUCT(StatusReport, type, message);
 
@@ -41,69 +42,65 @@ MAKE_REFLECT_STRUCT(StatusReport, type, message);
  */
 DEFINE_NOTIFICATION_TYPE(lang_status, StatusReport, "language/status");
 
+enum class MessageType
+{
 
-enum class MessageType {
-
-        /**
+    /**
          * An error message.
          */
-        Error=(1),
+    Error = (1),
 
-        /**
+    /**
          * A warning message.
          */
-         Warning=(2),
+    Warning = (2),
 
-         /**
+    /**
           * An information message.
           */
-          Info=(3),
+    Info = (3),
 
-          /**
+    /**
            * A log message.
            */
-           Log=(4)
+    Log = (4)
 };
 MAKE_REFLECT_TYPE_PROXY(MessageType);
 
+struct ActionableNotification
+{
 
-struct ActionableNotification {
-
-
-
-        /**
+    /**
          * The message type. See {
          *
          */
 
-         MessageType severity;
-        /**
+    MessageType severity;
+    /**
          * The actual message
          *
          */
 
-         std::string message;
+    std::string message;
 
-        /**
+    /**
          * Optional data
          *
          */
 
-        boost::optional<lsp::Any> data;
+    optional<lsp::Any> data;
 
-
-        /**
+    /**
          * Optional commands
          *
          */
 
-         std::vector<lsCommandWithAny> commands;
+    std::vector<lsCommandWithAny> commands;
 
-         MAKE_SWAP_METHOD(ActionableNotification, severity, message, data, commands)
+    MAKE_SWAP_METHOD(ActionableNotification, severity, message, data, commands)
 };
 MAKE_REFLECT_STRUCT(ActionableNotification, severity, message, data, commands)
 
-
 /**
  * The actionable notification is sent from a server to a client to ask the
  * client to display a particular message in the user interface, and possible
@@ -111,33 +108,26 @@ MAKE_REFLECT_STRUCT(ActionableNotification, severity, message, data, commands)
  */
 DEFINE_NOTIFICATION_TYPE(lang_actionableNotification, ActionableNotification, "language/actionableNotification");
 
+struct ProgressReport
+{
+    std::string ToString() const;
 
+    std::string id;
 
-struct  ProgressReport {
-        std::string ToString() const;
+    std::string task;
 
-        std::string id;
+    std::string subTask;
 
+    std::string status;
 
-        std::string task;
+    int totalWork = 0;
 
+    int workDone = 0;
 
-        std::string subTask;
-
-
-        std::string status;
-
-         int totalWork = 0;
-
-
-         int workDone = 0;
-
-
-         bool complete = false;
-         MAKE_SWAP_METHOD(ProgressReport, id, task, subTask, status, workDone, complete);
+    bool complete = false;
+    MAKE_SWAP_METHOD(ProgressReport, id, task, subTask, status, workDone, complete);
 };
 
-
 MAKE_REFLECT_STRUCT(ProgressReport, id, task, subTask, status, workDone, complete);
 
 /**
@@ -146,24 +136,25 @@ MAKE_REFLECT_STRUCT(ProgressReport, id, task, subTask, status, workDone, complet
  */
 DEFINE_NOTIFICATION_TYPE(lang_progressReport, ProgressReport, "language/progressReport");
 
-enum EventType {
-        /**
+enum EventType
+{
+    /**
          * classpath updated event.
          */
-        ClasspathUpdated = (100),
+    ClasspathUpdated = (100),
 
-        /**
+    /**
          * projects imported event.
          */
-         ProjectsImported = (200)
+    ProjectsImported = (200)
 };
 
 struct EventNotification
 {
-        int eventType;
-        lsp::Any data;
-        std::string ToString() const;
-        MAKE_SWAP_METHOD(EventNotification, eventType, data)
+    int eventType;
+    lsp::Any data;
+    std::string ToString() const;
+    MAKE_SWAP_METHOD(EventNotification, eventType, data)
 };
 MAKE_REFLECT_STRUCT(EventNotification, eventType, data);
 
