@@ -1,28 +1,26 @@
 #pragma once
 
-
 #include "LibLsp/JsonRpc/NotificationInMessage.h"
 
 #include "LibLsp/lsp/lsTextDocumentItem.h"
 
 // Open, view, change, close file
-namespace TextDocumentDidOpen {
+namespace TextDocumentDidOpen
+{
 
-  struct Params {
+struct Params
+{
     lsTextDocumentItem textDocument;
 
-
-
-   /**
+    /**
   * Legacy property to support protocol version 1.0 requests.
   */
     optional<std::string> text;
 
-   MAKE_SWAP_METHOD(TextDocumentDidOpen::Params, textDocument, text);
+    MAKE_SWAP_METHOD(TextDocumentDidOpen::Params, textDocument, text);
+};
 
-  };
-
-}
+} // namespace TextDocumentDidOpen
 MAKE_REFLECT_STRUCT(TextDocumentDidOpen::Params, textDocument, text);
 
 /**
@@ -32,8 +30,7 @@ MAKE_REFLECT_STRUCT(TextDocumentDidOpen::Params, textDocument, text);
  * using the document's uri.
  *
  * Registration Options: TextDocumentRegistrationOptions
- */;
-
+ */
+;
 
 DEFINE_NOTIFICATION_TYPE(Notify_TextDocumentDidOpen, TextDocumentDidOpen::Params, "textDocument/didOpen");
-
