@@ -10,6 +10,7 @@
 #include "types.h"
 #include "errormsg.h"
 #include "genv.h"
+#include "coenv.h"
 #include "stm.h"
 #include "settings.h"
 #include "vm.h"
@@ -101,6 +102,7 @@ public:
   penv() : _ge(0), _pd() {
     // Push the processData first, as it needs to be on the stack before genv
     // is initialized.
+    _pd.topPos = nullPos;
     processDataStack.push(&_pd);
     _ge = new genv;
   }
@@ -279,7 +281,8 @@ void itree::doList() {
   if (tree) {
     penv pe;
     record *r=tree->transAsFile(pe.ge(), symbol::trans(getName()));
-    r->e.list(r);
+    if(r)
+      r->e.list(r);
   }
 }
 
@@ -289,7 +292,7 @@ void itree::run(coenv &e, istack &s, transMode tm) {
     for(mem::list<runnable *>::iterator r=tree->stms.begin();
         r != tree->stms.end(); ++r) {
       processData().fileName=(*r)->getPos().filename();
-      if(!em.errors() || getSetting<bool>("debug"))
+      if(!em.errors() || debug)
         runRunnable(*r,e,s,tm);
     }
   }
@@ -593,7 +596,7 @@ class iprompt : public icore {
   // line is treated as a normal line of code.
   // commands is a map of command names to methods which implement the commands.
   typedef bool (iprompt::*command)(coenv &, istack &, commandLine);
-  typedef mem::map<CONST string, command> commandMap;
+  typedef mem::map<const string, command> commandMap;
   commandMap commands;
 
   bool exit(coenv &, istack &, commandLine cl) {
@@ -649,7 +652,7 @@ class iprompt : public icore {
 #define ADDCOMMAND(name, func)                  \
     commands[#name]=&iprompt::func
 
-    // keywords.pl looks for ADDCOMMAND to identify special commands in the
+    // keywords.py looks for ADDCOMMAND to identify special commands in the
     // auto-completion.
     ADDCOMMAND(quit,exit);
     ADDCOMMAND(q,q);
@@ -701,7 +704,7 @@ class iprompt : public icore {
   // detecting it in multiline mode).
   string getline(bool continuation) {
     string prompt;
-    if(!getSetting<bool>("xasy"))
+    if(!settings::xasy)
       prompt=getSetting<string>(continuation ? "prompt2" : "prompt");
     string line=interact::simpleline(prompt);
 
@@ -744,7 +747,7 @@ class iprompt : public icore {
 
         icode i(code);
         i.run(e,s,TRANS_INTERACTIVE);
-      } else if(getSetting<bool>("xasy")) {
+      } else if(settings::xasy) {
         block *code=parseXasyLine(line);
 
         icode i(code);
