@@ -17,10 +17,6 @@
 #include "fftw++.h"
 #endif
 
-#if defined(HAVE_LIBCURSES) && defined(HAVE_LIBREADLINE)
-#include <readline/readline.h>
-#endif
-
 void interruptHandler(int)
 {
 #ifdef HAVE_LIBFFTW3
@@ -29,8 +25,6 @@ void interruptHandler(int)
   em.Interrupt(true);
 }
 
-bool hangup=false;
-
 int returnCode()
 {
   return em.processStatus() || interact::interactive ? 0 : 1;
@@ -57,5 +51,4 @@ void signalHandler(int)
 
 void hangup_handler(int sig)
 {
-  hangup=true;
 }
