@@ -4,10 +4,6 @@
  * Render 3D Bezier paths and surfaces.
  *****/
 
-#ifdef __CYGWIN__
-#define _POSIX_C_SOURCE 200809L
-#endif
-
 #include <stdlib.h>
 #include <fstream>
 #include <cstring>
