@@ -19,17 +19,14 @@
  *
  *************/
 
-#ifdef __CYGWIN__
-#define _POSIX_C_SOURCE 200809L
-#endif
-
 #include <iostream>
 #include <cstdlib>
 #include <cerrno>
-#include <sys/wait.h>
 #include <sys/types.h>
 
-#define GC_PTHREAD_SIGMASK_NEEDED
+#if !defined(_WIN32)
+#include <sys/wait.h>
+#endif
 
 #include "common.h"
 
@@ -37,29 +34,31 @@
 #include <sigsegv.h>
 #endif
 
+#define GC_PTHREAD_SIGMASK_NEEDED
+
+#ifdef HAVE_LSP
+#include "lspserv.h"
+#endif
+
+#include "exithandlers.h"
 #include "errormsg.h"
 #include "fpu.h"
 #include "settings.h"
 #include "locate.h"
 #include "interact.h"
 #include "fileio.h"
+#include "stack.h"
 
 #ifdef HAVE_LIBFFTW3
 #include "fftw++.h"
 #endif
 
-#ifdef HAVE_LSP
-#include "lspserv.h"
+#if defined(_WIN32)
+#include <combaseapi.h>
 #endif
 
 #include "stack.h"
 
-#ifdef HAVE_LIBCURSES
-#ifdef HAVE_LIBREADLINE
-#include <readline/readline.h>
-#endif
-#endif
-
 using namespace settings;
 
 using interact::interactive;
@@ -109,31 +108,10 @@ void setsignal(void (*handler)(int))
                                 mystack,sizeof (mystack));
   sigsegv_install_handler(&sigsegv_handler);
 #endif
+#if !defined(_WIN32)
   Signal(SIGBUS,handler);
-  Signal(SIGFPE,handler);
-}
-
-void signalHandler(int)
-{
-  // Print the position and trust the shell to print an error message.
-  em.runtime(vm::getPos());
-
-  Signal(SIGBUS,SIG_DFL);
-  Signal(SIGFPE,SIG_DFL);
-}
-
-void interruptHandler(int)
-{
-#ifdef HAVE_LIBFFTW3
-  fftwpp::saveWisdom();
 #endif
-  em.Interrupt(true);
-}
-
-bool hangup=false;
-void hangup_handler(int sig)
-{
-  hangup=true;
+  Signal(SIGFPE,handler);
 }
 
 struct Args
@@ -143,11 +121,6 @@ struct Args
   Args(int argc, char **argv) : argc(argc), argv(argv) {}
 };
 
-int returnCode()
-{
-  return em.processStatus() || interact::interactive ? 0 : 1;
-}
-
 void *asymain(void *A)
 {
   setsignal(signalHandler);
@@ -157,6 +130,11 @@ void *asymain(void *A)
   fftwpp::wisdomName=".wisdom";
 #endif
 
+#if defined(_WIN32)
+  // see https://learn.microsoft.com/en-us/windows/win32/api/shellapi/nf-shellapi-shellexecuteexa
+  CoInitializeEx(nullptr, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
+#endif
+
   if(interactive) {
     Signal(SIGINT,interruptHandler);
 #ifdef HAVE_LSP
@@ -191,8 +169,11 @@ void *asymain(void *A)
     int n=numArgs();
     if(n == 0) {
       int inpipe=intcast(settings::getSetting<Int>("inpipe"));
-      if(inpipe >= 0) {
+      bool hasInpipe=inpipe >= 0;
+      if(hasInpipe) {
+#if !defined(_WIN32)
         Signal(SIGHUP,hangup_handler);
+#endif
         camp::openpipeout();
         fprintf(camp::pipeout,"\n");
         fflush(camp::pipeout);
@@ -231,8 +212,12 @@ void *asymain(void *A)
 #endif
 
   if(getSetting<bool>("wait")) {
+#if defined(_WIN32)
+#pragma message("TODO: wait option not implement yet")
+#else
     int status;
     while(wait(&status) > 0);
+#endif
   }
 #ifdef HAVE_GL
 #ifdef HAVE_PTHREAD
@@ -249,14 +234,6 @@ void *asymain(void *A)
   exit(returnCode());
 }
 
-void exitHandler(int)
-{
-#if defined(HAVE_READLINE) && defined(HAVE_LIBCURSES)
-  rl_cleanup_after_signal();
-#endif
-  exit(returnCode());
-}
-
 int main(int argc, char *argv[])
 {
 #ifdef HAVE_LIBGSL
@@ -273,7 +250,12 @@ int main(int argc, char *argv[])
 
   Args args(argc,argv);
 #ifdef HAVE_GL
-#ifdef __APPLE__
+#if defined(__APPLE__) || defined(_WIN32)
+
+#if defined(_WIN32)
+#pragma message("TODO: Check if (1) we need detach-based gl renderer")
+#endif
+
   bool usethreads=true;
 #else
   bool usethreads=view();
@@ -284,14 +266,36 @@ int main(int argc, char *argv[])
   if(gl::glthread) {
     pthread_t thread;
     try {
-      if(pthread_create(&thread,NULL,asymain,&args) == 0) {
+#if defined(_WIN32)
+      auto asymainPtr = [](void* args) -> void*
+      {
+#if defined(USEGC)
+        GC_stack_base gsb {};
+        GC_get_stack_base(&gsb);
+        GC_register_my_thread(&gsb);
+#endif
+        auto* ret = asymain(args);
+
+#if defined(USEGC)
+        GC_unregister_my_thread();
+#endif
+        return reinterpret_cast<void*>(ret);
+      };
+#else
+      auto* asymainPtr = asymain;
+#endif
+      if(pthread_create(&thread,NULL,asymainPtr,&args) == 0) {
         gl::mainthread=pthread_self();
+#if !defined(_WIN32)
         sigset_t set;
         sigemptyset(&set);
         sigaddset(&set, SIGCHLD);
         pthread_sigmask(SIG_BLOCK, &set, NULL);
+#endif
         for(;;) {
+#if !defined(_WIN32)
           Signal(SIGURG,exitHandler);
+#endif
           camp::glrenderWrapper();
           gl::initialize=true;
         }
@@ -306,9 +310,3 @@ int main(int argc, char *argv[])
 #endif
   asymain(&args);
 }
-
-#ifdef USEGC
-GC_API void GC_CALL GC_throw_bad_alloc() {
-  std::bad_alloc();
-}
-#endif
