@@ -16,13 +16,12 @@
 #include "drawlayer.h"
 #include "drawsurface.h"
 #include "drawpath3.h"
-#include "win32helpers.h"
+#include "seconds.h"
 
 #if defined(_WIN32)
 #include <Windows.h>
 #include <shellapi.h>
 #include <cstdio>
-#define unlink _unlink
 #endif
 
 #include <thread>
@@ -525,15 +524,7 @@ bool picture::texprocess(const string& texname, const string& outname,
           string dvipsrc=getSetting<string>("dir");
           if(dvipsrc.empty()) dvipsrc=systemDir;
           dvipsrc += dirsep+"nopapersize.ps";
-#if !defined(_WIN32)
-          setenv("DVIPSRC",dvipsrc.c_str(),1);
-#else
-          auto setEnvResult = SetEnvironmentVariableA("DVIPSRC",dvipsrc.c_str());
-          if (!setEnvResult)
-          {
-              camp::reportError("Cannot set DVIPSRC environment variable");
-          }
-#endif
+          setenv("DVIPSRC",dvipsrc.c_str(),true);
           string papertype=getSetting<string>("papertype") == "letter" ?
             "letterSize" : "a4size";
           cmd.push_back(getSetting<string>("dvips"));
@@ -854,7 +845,7 @@ bool picture::postprocess(const string& prename, const string& outname,
   if(pdftex || !epsformat) {
     if(pdfformat) {
       if(pdftex) {
-        status=rename(prename.c_str(),outname.c_str());
+        status=renameOverwrite(prename.c_str(),outname.c_str());
         if(status != 0)
           reportError("Cannot rename "+prename+" to "+outname);
       } else status=epstopdf(prename,outname);
@@ -885,6 +876,8 @@ bool picture::postprocess(const string& prename, const string& outname,
         cmd.push_back("-r"+String(res)+"x"+String(res));
         push_split(cmd,getSetting<string>("gsOptions"));
         cmd.push_back("-sOutputFile="+outname);
+        cmd.push_back("-dTextAlphaBits=4");
+        cmd.push_back("-dGraphicsAlphaBits=4");
         cmd.push_back(prename);
         status=System(cmd,0,true,"gs","Ghostscript");
       } else if(!svg && !xasy) {
@@ -1389,9 +1382,9 @@ bool picture::shipout(picture *preamble, const string& Prefix,
       if(Labels) {
         tex->epilogue();
         if(context) prefix=stripDir(prefix);
+        delete tex;
         status=texprocess(texname,dvi ? outname : prename,prefix,
                           bboxshift,dvi);
-        delete tex;
         if(!keep) {
           for(mem::list<string>::iterator p=files.begin(); p != files.end();
               ++p)
