@@ -7,11 +7,14 @@
 #include <sys/resource.h>
 #endif
 
-namespace utils {
 
 #ifdef _WIN32
 #include <Windows.h>
 #define getpid GetCurrentProcessId
+#endif
+
+namespace utils {
+#ifdef _WIN32
 inline double cpuTime() {
   FILETIME a,b,c,d;
   return GetProcessTimes(GetCurrentProcess(),&a,&b,&c,&d) != 0 ?
@@ -80,8 +83,10 @@ public:
   double nanoseconds(bool reset=false) {
     auto Stop=std::chrono::steady_clock::now();
     double stop=cpuTime();
-    double ns=std::min((double) std::chrono::duration_cast<std::chrono::nanoseconds>
-                       (Stop-Start).count(),stop-start);
+    double ns=std::chrono::duration_cast<std::chrono::nanoseconds>(Stop-Start).count();
+    double cputime=stop-start;
+    if((cputime > 0 && cputime < ns) || ns == 0) ns=cputime;
+
     if(reset) {
       Start=Stop;
       start=stop;
@@ -96,4 +101,14 @@ public:
 
 }
 
+// POSIX--style rename that allows overwriting
+inline int renameOverwrite(const char *oldpath, const char *newpath) {
+#if defined(_WIN32)
+  return !MoveFileExA(
+    oldpath, newpath, MOVEFILE_REPLACE_EXISTING | MOVEFILE_COPY_ALLOWED);
+#else
+  return rename(oldpath,newpath);
+#endif
+}
+
 #endif
