@@ -536,15 +536,25 @@ public:
     return 0;
   }
 
+
+#ifdef __clang__
+#elif __GNUC__
+#pragma GCC push_options
+#pragma GCC optimize("O2")
+#endif
   void add(ty *t) {
     if (t->kind == ty_overloaded) {
       overloaded *ot = (overloaded *)t;
       copy(ot->sub.begin(), ot->sub.end(),
            inserter(this->sub, this->sub.end()));
-    }
+  }
     else
       sub.push_back(t);
   }
+#ifdef __clang__
+#elif __GNUC__
+#pragma GCC pop_options
+#endif
 
   // Only add a type distinct from the ones currently in the overloaded type.
   // If special is false, just the distinct signatures are added.
